#[non_exhaustive]pub enum PropagateTo {
All,
Unchanged,
None,
}Available on (crate features
client or server) and crate feature unstable-msc4466 only.Expand description
Controls which rooms the server should send an updated m.room.member event in
when changing displayname or avatar_url in a user’s profile. Defined by MSC4466.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
All
The server must send a m.room.member event in all of the user’s
joined rooms.
Unchanged
The server must only send a m.room.member event in rooms where the profile
field being updated does not differ from its value in the user’s global profile data.
None
The server must not send a m.room.member event to any rooms.
Implementations