#[non_exhaustive]pub struct UserProfileChanges {
pub updated: BTreeMap<ProfileFieldName, Value>,
pub removed: Vec<ProfileFieldName>,
}Available on crate features
client or server only.Expand description
A collection of changes to be applied to a user’s profile.
This type is not supposed to be used directly, but applied to an existing
UserProfile. If a profile doesn’t exist, the changes should be applied
to an empty one.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.updated: BTreeMap<ProfileFieldName, Value>Fields that have been newly set, or updated.
removed: Vec<ProfileFieldName>Fields that have been removed from the profile.
Implementations
Sourceimpl UserProfileChanges
impl UserProfileChanges
Sourcepub fn new() -> UserProfileChanges
pub fn new() -> UserProfileChanges
Creates a new empty UserProfileUpdate.
Sourcepub fn get_updated_static<F>(
&self,
) -> Result<Option<<F as StaticProfileField>::Value>, Error>where
F: StaticProfileField,
pub fn get_updated_static<F>(
&self,
) -> Result<Option<<F as StaticProfileField>::Value>, Error>where
F: StaticProfileField,
Returns the updated value of the given StaticProfileField.
Returns Ok(Some(_)) if an update to the field is included and the value was deserialized
successfully, Ok(None) if the field update is not included, or an error if deserialization
of the value failed.
Sourcepub fn insert_updated_value(&mut self, value: ProfileFieldValue)
pub fn insert_updated_value(&mut self, value: ProfileFieldValue)
Inserts an update for the supplied profile field value.